/* attribute 'node_level' - level of node (from root) */
/* $Id: at_node_level.h,v 1.1 1992/10/29 04:35:01 coleman Exp $ */

#ifndef at_node_level_h
# define at_node_level_h 1

# include "aglo.h"

void at_setup_node_level(aglo_graph graph);

#endif /* at_node_level_h */
